# airless-slack

[![PyPI version](https://badge.fury.io/py/airless-email.svg)](https://badge.fury.io/py/airless-email)

airless-slack were build to work with slack messages using [Airless](https://github.com/astercapital/airless) module.
